@@ -14,6 +14,9 @@ class RedisPWX:
     def add(self, collection, key, value):
         self.redis.hset(name=collection, key=key, value=value)
 
+    def add_many(self, collection, values):
+        self.redis.hmset(name=collection, mapping=values)
+
     def get_by_key(self, collection, key):
         result = self.redis.hget(name=collection, key=key)
 
